@@ -1,14 +1,14 @@
 from .structs import (
-    OrderSide, OrderStatus, OrderType, Pair, Period, Candle, Trade
+    OrderSide, OrderStatus, OrderType, Pair, Period, Candle, Trade, Coin
 )
 from .base import Exchange, Account
 from .api import ApiError, ApiProvider
 
 __all__ = [
-    'OrderSide', 'OrderStatus', 'OrderType', 'Pair',
+    'OrderSide', 'OrderStatus', 'OrderType', 'Pair', 'Coin'
     'Period', 'Candle', 'Trade',
     'Exchange', 'Account',
     'ApiError', 'ApiProvider'
 ]
 
-VERSION = '0.3.1'
+VERSION = '0.3.4'
