@@ -4,7 +4,8 @@ from typing import List
 
 from .api import ApiProvider, ApiError
 from .structs import (
-    Pair, OrderSide, OrderStatus, OrderType, Period, Candle, Trade
+    Pair, OrderSide, OrderStatus, OrderType, Period, Candle, Trade,
+    OrderInBook, OrderBook
 )
 
 
@@ -86,8 +87,20 @@ class Exchange:
                     Pair(data['instrument_name'])
                 )
 
-    async def listen_orderbook(self, *pairs: List[Pair]):
-        raise NotImplementedError('Will be implemented soon')
+    async def listen_orderbook(
+            self, *pairs: List[Pair], depth: int = 150) -> OrderBook:
+        channels = [f'book.{pair}.{depth}' for pair in pairs]
+        async for data in self.api.listen('market', *channels):
+            pair = Pair(data['instrument_name'])
+            buys = [
+                OrderInBook(*order, OrderSide.BUY)
+                for order in data['data'][0]['bids']
+            ]
+            sells = [
+                OrderInBook(*order, OrderSide.SELL)
+                for order in reversed(data['data'][0]['asks'])
+            ]
+            yield OrderBook(buys, sells, pair)
 
 
 class Account:
@@ -268,7 +281,8 @@ class Account:
     async def listen_balance(self):
         async for data in self.api.listen(
                 'user', 'user.balance', sign=True):
-            yield data
+            for balance in data.get('data', []):
+                yield balance
 
     async def listen_orders(self, pair: Pair):
         async for data in self.api.listen(
@@ -276,8 +290,3 @@ class Account:
             for order in data.get('data', []):
                 order['id'] = int(order.pop('order_id'))
                 yield order
-
-    # async def listen_trades(self, pair: Pair):
-    #     async for data in self.api.listen(
-    #             'user', f'user.order.{pair.value}', sign=True):
-    #         yield data
