@@ -1,5 +1,6 @@
 import enum
 
+from typing import List
 from dataclasses import dataclass
 
 
@@ -56,6 +57,8 @@ class Coin(str, enum.Enum):
     ALGO = 'ALGO'
     KNC = 'KNC'
     NEO = 'NEO'
+    PAXG = 'PAXG'
+    BAT = 'BAT'
 
     USDT = 'USDT'
     USDC = 'USDC'
@@ -101,6 +104,8 @@ class Pair(str, enum.Enum):
     KNC_USDT = 'KNC_USDT'
     NEO_USDT = 'NEO_USDT'
     DAI_USDT = 'DAI_USDT'
+    PAXG_USDT = 'PAXG_USDT'
+    BAT_USDT = 'BAT_USDT'
 
     MCO_CRO = 'MCO_CRO'
     ETH_CRO = 'ETH_CRO'
@@ -120,6 +125,8 @@ class Pair(str, enum.Enum):
     KNC_CRO = 'KNC_CRO'
     NEO_CRO = 'NEO_CRO'
     DAI_CRO = 'DAI_CRO'
+    PAXG_CRO = 'PAXG_CRO'
+    BAT_CRO = 'BAT_CRO'
 
     CRO_USDC = 'CRO_USDC'
 
@@ -143,3 +150,26 @@ class Trade:
     quantity: float
     side: OrderSide
     pair: Pair
+
+
+@dataclass
+class OrderInBook:
+    price: float
+    quantity: float
+    count: int
+    side: OrderSide
+
+    @property
+    def volume(self) -> float:
+        return self.price * self.quantity
+
+
+@dataclass
+class OrderBook:
+    buys: List[OrderInBook]
+    sells: List[OrderInBook]
+    pair: Pair
+
+    @property
+    def spread(self) -> float:
+        return (self.sells[0].price / self.buys[0].price - 1) * 100
